@@ -485,9 +485,9 @@ class Materials(BaseCollections):
         return iter(self._materials)
 
     def __getitem__(self, index):
-        if index not in self._dmap.keys():
-            raise ValueError(f'Material name "{index}" not found')
-        result = self._dmap[index]
+        # if index not in self._dmap.keys():
+        #     raise ValueError(f'Material name "{index}" not found')
+        result = self._materials[index]
         return Materials(result) if isinstance(index, slice) else result
 
     def __eq__(self, other):
@@ -730,7 +730,20 @@ class Nodes:
             nodes = toolz.unique(nodes, key=attrgetter("id"))
 
         self._nodes = sorted(nodes, key=attrgetter("x", "y", "z"))
-        self._idmap = {n.id: n for n in self._nodes}
+        self._idmap = {n.id: n for n in sorted(self._nodes, key=attrgetter("id"))}
+        self._maxid = max(self._idmap.keys()) if len(self._nodes) > 0 else 0
+        self._bbox = self._get_bbox() if len(self._nodes) > 0 else None
+
+    def renumber(self):
+        """
+        Ensures that the node numberings starts at 1 and has no holes in its numbering.
+
+        """
+        for i, n in enumerate(sorted(self._nodes, key=attrgetter("id")), start=1):
+            if i != n.id:
+                n.id = i
+
+        self._idmap = {n.id: n for n in sorted(self._nodes, key=attrgetter("id"))}
         self._maxid = max(self._idmap.keys()) if len(self._nodes) > 0 else 0
         self._bbox = self._get_bbox() if len(self._nodes) > 0 else None
 
@@ -857,14 +870,7 @@ class Nodes:
 
     @property
     def vol_cog(self):
-        def get_middle(bbox, i):
-            return (bbox[i][0][i] + bbox[i][1][i]) / 2
-
-        return (
-            get_middle(self.bbox, 0),
-            get_middle(self.bbox, 1),
-            get_middle(self.bbox, 2),
-        )
+        return tuple([(self.bbox[i][0][i] + self.bbox[i][1][i]) / 2 for i in range(3)])
 
     @property
     def max_nid(self):
@@ -887,11 +893,7 @@ class Nodes:
 
         p = np.array(p) if type(p) is (list, tuple) else p
         if p is not None and vol_cyl is None and vol_box is None:
-            vol = [
-                (p[0] - tol, p[0] + tol),
-                (p[1] - tol, p[1] + tol),
-                (p[2] - tol, p[2] + tol),
-            ]
+            vol = [(coord - tol, coord + tol) for coord in p]
         elif vol_box is not None:
             vol = list(zip(p, vol_box))
         elif vol_cyl is not None and p is not None:
